@@ -15,7 +15,8 @@
 // - Input matrix provided with zero-base numbering.
 //
 
-HighsInt genrcm(HighsInt node_num, HighsInt adj_num, const HighsInt adj_row[],
-                const HighsInt adj[], HighsInt perm[]);
+HighsInt Highs_genrcm(HighsInt node_num, HighsInt adj_num,
+                      const HighsInt adj_row[], const HighsInt adj[],
+                      HighsInt perm[]);
 
 #endif
\ No newline at end of file
